mode_colors = {
    "s) speak aloud": 22,
    "z) auto next": 22,
    "s) speak on": 161,
    "paused": 161,
}
nod_colors = {
    "yes": 77,
    "OK": 36,
    "OK, I get it now": 36,
    "I agree!": 22,
    "answer": 41,
    "idea": 151,
    "correct": 30,
    "incorrect": 161,
    "background": 93,
    "archive": 145,
    "okay": 36,
    "okay, okay!": 25,
    "okay, go on": 30,
    "okay?": 240,
    "not reviewed": 143,
    "goal": 22,
    "got an idea!": 32,
    "skipped": 245,
    "skip": 245,
    "I see!": 71,
    "interesting!": 76,
    "favorite!": 219,
    "interesting, so?": 76,
    "proposed solution": 32,
    "contribution": 77,
    "feature": 77,
    "constraint": 97,
    "important!": 141,
    "point!": 142,
    "main idea!": 142,
    "has an idea!": 115,
    "didn't get!": 161,
    "didn't get": 161,
    "unclear": 161,
    "question": 136,
    "comment": 141,
    "didn't get the article": 161,
    "didn't get, needs review": 161,
    "okay, never mind": 145,
    "what?!": 161,
    "what?! needs review": 161,
    "don't think so": 179,
    "not sure!": 179,
    "what?!": 31,
    "didn't get, so?": 196,
    "so?": 39,
    "Let's continue": 39,
    "continue": 39,
    "okay, continue": 39,
    "okay, so?": 39,
    "almost got the idea?": 32,
    "explain more": 178,
    "why?": 59,
    "needs review": 177,
    "review later": 177,
    "to read later": 177,
    "check later": 186,
    "problem": 179,
    "definition": 250,
    "got it!": 69,
    "got the idea!": 69,
}

cW = 7
cR = 1
cG = 30
cY = 5
cB = 27
clB = 33
cPink = 15
cC = 9
clC = 16
clY = 13
cGray = 10
clGray = 250
clG = 12
cllC = 83
cO = 94
back_color = None

TEXT_COLOR = 35 
ITEM_COLOR = 32 
TITLE_COLOR = 30
DIM_COLOR = 233
COMMENT_COLOR = 39

CUR_ITEM_COLOR = 100
HL_COLOR = 101
INPUT_COLOR = 102
INFO_COLOR = 103
ERR_COLOR = 104
MSG_COLOR = 105
WARNING_COLOR = 106
TEMP_COLOR = 107
TEMP_COLOR2 = 108
SEL_ITEM_COLOR = 109

color_map = {
    "cur-item-color": CUR_ITEM_COLOR,
    "sel-item-color": SEL_ITEM_COLOR,
    "highlight-color": HL_COLOR,
    "hl-text-color": HL_COLOR,
    "back-color": TEXT_COLOR,
    "input-color": INPUT_COLOR,
}

hl_colors = [(137,52), (234, 243), (234, 137), (234, 95), (137,236), (137,234), (144, 234), (95,233), (95, 17), (245,17), (245,235)]

