rc_inst = """
    Please find the answers to the following questions in the given text. To do this, navigate to each question, then press s to start reading the text.
    To find the answer, scan the text sentence by sentence with arrow keys. Then press <Enter> on the sentence containing the answer. If it's the correct sentence, the sentence is highlighted in green, otherwise, it's highlighted in red.
    To mark the answer span,  navigate to its starting word, then either hold the <Shift> key or press the v key, then move forward to the ending word and press v again.
    In the end, press <Enter> to validate your answer. Some questions cannot be answered by the given text, press s to stop reading and return back to the question and then press - to specify it as 'impossible to answer'. You can also skip a question by pressing <Left> when it's selected.
"""
